Structs
- Client
Cert Paths - Client certificate and key paths for mTLS authentication
- TlsFile
Paths
Functions
- build_
client_ cert_ with_ custom_ cn - Build a client certificate with a custom common name (CN) field Redis 8.6+ allows certificate-based authentication where the common name (CN) is mapped to an ACL username
- build_
keys_ and_ certs_ for_ tls - build_
keys_ and_ certs_ for_ tls_ ext - get_
listener_ on_ free_ port - get_
random_ available_ port - Finds a random open port available for listening at, by spawning a TCP server with port “zero” (which prompts the OS to just use any available port). Between calling this function and trying to bind to this port, the port may be given to another process, so this must be used with care (since here we only use it for tests, it’s mostly okay).